@@ -1,9 +1,10 @@
 """Quaidan is a python wrapper for mod_proxy_balancer's balancer
 manager. The starting point for all interactions is a
-``BalancerManager`` object. This object provides the status.
+``BalancerManager`` object. This object provides the status and
+can be used to update members.
 """
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
 from quaidan.client import Client
 from quaidan.status import parse_balancer_manager_page
@@ -24,3 +25,10 @@ class BalancerManager(object):
         """
         page = self._client.get_balancer_manager_page()
         return parse_balancer_manager_page(page)
+
+    def send_command(self, command):
+        """Sends a command to the balancer.
+
+        :param command: the command that is send to the balancer.
+        """
+        self._client.send_form(command.to_form())
